"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deploy = void 0;
const child_process_1 = require("child_process");
const fs_1 = require("fs");
const path_1 = require("path");
const config_1 = require("../config");
const ora_1 = __importDefault(require("ora"));
function deploy() {
    const spinner = (0, ora_1.default)('Deploying functions').start();
    const functions = (0, fs_1.readdirSync)(config_1.config.functionsDir).filter((f) => f.endsWith('.ts'));
    for (const functionFile of functions) {
        const functionName = `${config_1.config.prefix}${config_1.config.prefix ? '-' : ''}${functionFile.replace('.ts', '')}`;
        spinner.text = `Deploying ${functionName}`;
        config_1.config.env.forEach((e) => {
            if (!process.env[e]) {
                throw new Error(`Missing environment variable ${e}`);
            }
        });
        (0, child_process_1.execSync)(`gcloud functions deploy ${functionName} \
      --runtime ${config_1.config.runtime} \
      --trigger-http \
      --region=${config_1.config.region} \
      --allow-unauthenticated \
      --source=${(0, path_1.join)(config_1.config.buildDir, functionName)} \
      --entry-point=${functionName} \
      ${config_1.config.env
            .map((e) => `--set-env-vars="${e}=${process.env[e]}"`)
            .join(' ')}`);
        spinner.succeed(`Deployed ${functionName}`);
    }
}
exports.deploy = deploy;
//# sourceMappingURL=deploy.js.map